@@ -297,18 +297,20 @@ def get_query_results(
     sql_file: str,
     return_type: str = DEFAULT_RETURN_TYPE,
     sql_params: dict = None,
-    timeout=DEFAULT_TIMEOUT,
-    location=DEFAULT_LOCATION,
+    timeout: int = DEFAULT_TIMEOUT,
+    location: str = DEFAULT_LOCATION,
+    index_label: str = None,
 ):
     """
     Runs query and returns the result as dataframe
 
-    :param return_type: file format to be returned (dict,dataframe,json,pyarrow); default is dataframe
+    :param return_type: file format to be returned (dict,dataframe,csv,json,json_string,pyarrow); default is dataframe
     :param service_account_file: relative location of service account file
     :param sql_file: relative location of sql file to read sql from
     :param sql_params: sql parameters dictionary
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
+    :param index_label: if given and return type is csv, table will be indexed with this column name
     :return: query result
     """
     client = connect(service_account_file=service_account_file)
@@ -321,6 +323,7 @@ def get_query_results(
         timeout=timeout,
         location=location,
         return_type=return_type,
+        index_label=index_label,
     )
 
 
