@@ -161,15 +161,17 @@ def select(
     timeout: int,
     location: str,
     return_type: str = DEFAULT_RETURN_TYPE,
+    index_label: str = None,
 ):
     """
     Runs a select query and returns results as dataframe
 
-    :param return_type: dataframe, json, json string, dictionary or pyarrow; default is dataframe
+    :param return_type: dataframe, json, json string, dictionary, csv or pyarrow; default is dataframe
     :param client: Client needed for API request
     :param sql: query sql
     :param timeout: job timeout parameter
     :param location: job location parameter
+    :param index_label: if given and return type is csv, table will be indexed with this column name
     :return: a dataframe of query result
     """
     job_config = bigquery.QueryJobConfig()
@@ -193,6 +195,11 @@ def select(
         return result.to_dataframe().to_dict(orient="records")
     elif return_type == "dataframe":
         return result.to_dataframe()
+    elif return_type == "csv":
+        if index_label:
+            return result.to_dataframe().to_csv(index_label=index_label)
+        else:
+            return result.to_dataframe().to_csv()
     elif return_type == "pyarrow":
         return result.to_arrow()
     else:
